On Fri, Mar 20 2020, Landry Breuil <lan...@openbsd.org> wrote:
> On Fri, Mar 20, 2020 at 07:31:52AM +0100, Rafael Sadowski wrote:
>> On Mon Mar 16, 2020 at 06:17:38AM +0100, Rafael Sadowski wrote:
>> > Simple update qtwebkit to the latest version 5.212.0 Alpha 4:
>> > 
>> > Release log:
>> > - https://github.com/qtwebkit/qtwebkit/releases/tag/qtwebkit-5.212.0-alpha4
>> > 
>> > Port changes:
>> > - Add missing python model after reading release notes "QtWebKit does
>> >   not require Python 2 anymore for building and can use Python 3
>> >   instead"
>> > - removed icu patched, it has been merged upstream.
>> > 
>> > Tested with otter-browser on amd64.
>> > 
>> 
>> I would like to see this in the next release.
>> 
>> > OK?
>> > 
>> > Index: Makefile
>> > ===================================================================
>> > RCS file: /cvs/ports/x11/qt5/qtwebkit/Makefile,v
>> > retrieving revision 1.19
>> > diff -u -p -u -p -r1.19 Makefile
>> > --- Makefile       25 Feb 2020 14:03:00 -0000      1.19
>> > +++ Makefile       16 Mar 2020 05:05:27 -0000
>> > @@ -9,15 +9,15 @@ CATEGORIES =             www
>> >  DPB_PROPERTIES =  parallel
>> >  
>> >  VERSION =         ${QT5_WEBKIT_VERSION}
>> > -DISTNAME =                qtwebkit-${QT5_WEBKIT_VERSION}-alpha3
>> > +DISTNAME =                qtwebkit-${QT5_WEBKIT_VERSION}-alpha4
>> >  PKGNAME =         qtwebkit-${QT5_WEBKIT_VERSION}
>> > -REVISION =                0
>> > +REVISION =                1
>> 
>> Any concept howto handle the version bump -alpha3 to -alpha4? We have
>> only rc[N], beta[N], pre[N], and pl[N]. Would it makes sense to add a
>> alpha[N]? We could of course also use EPOCH here.
>
> adding support for alpha[N] would be in suffix_compare in PackageName.pm
> (and from_string), but that would only work (afaik) if the suffix was
> directly near the version, ie 5.13.2alpha3 (not 5.13.2-alpha3).

I suspect that the lack of support for alpha[N] is intentional, as in
"You should not put alpha-quality software in the ports tree."

The current situation is that we have ports using alpha releases in the
tree, and I see no reason to arbitrarily draw a line between alpha and
beta releases.

Diff below, not tested much yet.  Thoughts?
cc'ing espie


Index: OpenBSD/PackageName.pm
===================================================================
RCS file: /cvs/src/usr.sbin/pkg_add/OpenBSD/PackageName.pm,v
retrieving revision 1.53
diff -u -p -r1.53 PackageName.pm
--- OpenBSD/PackageName.pm      7 Nov 2019 15:35:23 -0000       1.53
+++ OpenBSD/PackageName.pm      20 Mar 2020 14:48:00 -0000
@@ -153,7 +153,7 @@ sub from_string
        my ($class, $string) = @_;
        my $o = bless { deweys => [ split(/\./o, $string) ],
                suffix => '', suffix_value => 0}, $class;
-       if ($o->{deweys}->[-1] =~ m/^(\d+)(rc|beta|pre|pl)(\d*)$/) {
+       if ($o->{deweys}->[-1] =~ m/^(\d+)(rc|alpha|beta|pre|pl)(\d*)$/) {
                $o->{deweys}->[-1] = $1;
                $o->{suffix} = $2;
                $o->{suffix_value} = $3;
@@ -193,10 +193,13 @@ sub suffix_compare
        if ($a->{suffix} gt $b->{suffix}) {
                return -suffix_compare($b, $a);
        }
        # order is '', beta, pre, rc
        # we know that a < b,
        if ($a->{suffix} eq '') {
                return 1;
+       }
+       if ($a->{suffix} eq 'alpha') {
+               return -1;
        }
        if ($a->{suffix} eq 'beta') {
                return -1;
@@ -193,10 +193,13 @@ sub suffix_compare
                return -suffix_compare($b, $a);
        }
-       # order is '', beta, pre, rc
+       # order is '', alpha, beta, pre, rc
        # we know that a < b,
        if ($a->{suffix} eq '') {



-- 
jca | PGP : 0x1524E7EE / 5135 92C1 AD36 5293 2BDF  DDCC 0DFA 74AE 1524 E7EE

Reply via email to